# python-friskby-controlpanel [![Build Status](https://travis-ci.org/FriskByBergen/python-friskby-controlpanel.svg?branch=master)](https://travis-ci.org/FriskByBergen/python-friskby-controlpanel)


Lets the Friskby device owner inspect and manage the Friskby system.

Starts a webservice with status reports on FriskbySubmitter, FriskbySampler, and FriskbyRunner.
